diff Core/SQLite/Transaction.cpp @ 59:c996319e90bc orthanc-renaming

renaming in Core
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:28:56 +0200
parents a15e90e5d6fc
children bdd72233b105
line wrap: on
line diff
--- a/Core/SQLite/Transaction.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/Transaction.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -36,7 +36,7 @@
 
 #include "Transaction.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace SQLite
   {
@@ -58,13 +58,13 @@
     {
       if (isOpen_) 
       {
-        throw PalanthirException("SQLite: Beginning a transaction twice!");
+        throw OrthancException("SQLite: Beginning a transaction twice!");
       }
 
       isOpen_ = connection_.BeginTransaction();
       if (!isOpen_)
       {
-        throw PalanthirException("SQLite: Unable to create a transaction");
+        throw OrthancException("SQLite: Unable to create a transaction");
       }
     }
 
@@ -72,7 +72,7 @@
     {
       if (!isOpen_) 
       {
-        throw PalanthirException("SQLite: Attempting to roll back a nonexistent transaction. "
+        throw OrthancException("SQLite: Attempting to roll back a nonexistent transaction. "
                                 "Did you remember to call Begin()?");
       }
 
@@ -85,7 +85,7 @@
     {
       if (!isOpen_) 
       {
-        throw PalanthirException("SQLite: Attempting to roll back a nonexistent transaction. "
+        throw OrthancException("SQLite: Attempting to roll back a nonexistent transaction. "
                                 "Did you remember to call Begin()?");
       }
 
@@ -93,7 +93,7 @@
 
       if (!connection_.CommitTransaction())
       {
-        throw PalanthirException("SQLite: Failure when committing the transaction");
+        throw OrthancException("SQLite: Failure when committing the transaction");
       }
     }
   }
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium